==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkXMLPMultiBlockDataWriter.java <==
// java wrapper for vtkXMLPMultiBlockDataWriter object
//

package vtk;
import vtk.*;

public class vtkXMLPMultiBlockDataWriter extends vtkXMLMultiBlockDataWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfPieces_2(int id0);
  public void SetNumberOfPieces(int id0)
    { SetNumberOfPieces_2(id0); }

  private native int GetNumberOfPieces_3();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_3(); }

  private native void SetStartPiece_4(int id0);
  public void SetStartPiece(int id0)
    { SetStartPiece_4(id0); }

  private native int GetStartPiece_5();
  public int GetStartPiece()
    { return GetStartPiece_5(); }

  private native void SetController_6(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_6(id0); }

  private native long GetController_7();
  public vtkMultiProcessController GetController() {
    long temp = GetController_7();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetWriteMetaFile_8(int id0);
  public void SetWriteMetaFile(int id0)
    { SetWriteMetaFile_8(id0); }

  public vtkXMLPMultiBlockDataWriter() { super(); }

  public vtkXMLPMultiBlockDataWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-aarch64.pkg.tar.xz: vtk/vtkXMLPMultiBlockDataWriter.java <==
// java wrapper for vtkXMLPMultiBlockDataWriter object
//

package vtk;
import vtk.*;

public class vtkXMLPMultiBlockDataWriter extends vtkXMLMultiBlockDataWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfPieces_2(int id0);
  public void SetNumberOfPieces(int id0)
    { SetNumberOfPieces_2(id0); }

  private native int GetNumberOfPieces_3();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_3(); }

  private native void SetStartPiece_4(int id0);
  public void SetStartPiece(int id0)
    { SetStartPiece_4(id0); }

  private native int GetStartPiece_5();
  public int GetStartPiece()
    { return GetStartPiece_5(); }

  private native void SetController_6(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_6(id0); }

  private native long GetController_7();
  public vtkMultiProcessController GetController() {
    long temp = GetController_7();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetWriteMetaFile_8(int id0);
  public void SetWriteMetaFile(int id0)
    { SetWriteMetaFile_8(id0); }

  public vtkXMLPMultiBlockDataWriter() { super(); }

  public vtkXMLPMultiBlockDataWriter(long id) { super(id); }
  public native long   VTKInit();

}
